import threading

import requests


class TraceClient:
    _TEST_URL = "http://xyz.rag-workflow.test.ke.com/api/tracer"

    @classmethod
    def instance(cls):
        if not hasattr(cls, "_instance"):
            cls._instance = cls()
        return cls._instance

    def publish(self, trace_data):
        thread = threading.Thread(target=self._send_request, args=(trace_data,))
        thread.start()

    def _send_request(self, trace_data):
        try:
            requests.post(f"{self._TEST_URL}/publish", json=trace_data)
        except Exception as e:
            print(f"Request failed: {e}")



class NodeInfo:
    def __init__(self, trace_id, node_key):
        self._trace_id = trace_id
        self._node_key = node_key
        self._event_data = {}

        # 其他系统字段
        self._endpoint = '__default_endpoint__'
        self._time_cost = -1

    def set(self, **kwargs):
        for key, value in kwargs.items():
            self._event_data[key] = value

    def endpoint(self, endpoint):
        self._endpoint = endpoint

    def time_cost(self, time_cost):
        self._time_cost = time_cost

    def event_data(self, event_data):
        self._event_data = event_data

    def to_dict(self):
        return {
            "trace_id": self._trace_id,
            "endpoint": self._endpoint,
            "node_key": self._node_key,
            "event_data": self._event_data,
            "time_cost": self._time_cost
        }
